# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: jobs/nbox_ws.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..jobs import job_pb2 as jobs_dot_job__pb2
from ..common import common_pb2 as common_dot_common__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12jobs/nbox_ws.proto\x12\x07jobs.ws\x1a\x0ejobs/job.proto\x1a\x13\x63ommon/common.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x7f\n\nJobRequest\x12&\n\tauth_info\x18\x01 \x01(\x0b\x32\x13.common.NBXAuthInfo\x12\x16\n\x03job\x18\x02 \x01(\x0b\x32\t.jobs.Job\x12\x31\n\x10integration_data\x18\x03 \x01(\x0b\x32\x17.common.IntegrationData\"\xb6\x01\n\x10UpdateJobRequest\x12&\n\tauth_info\x18\x01 \x01(\x0b\x32\x13.common.NBXAuthInfo\x12\x16\n\x03job\x18\x02 \x01(\x0b\x32\t.jobs.Job\x12/\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x31\n\x10integration_data\x18\x04 \x01(\x0b\x32\x17.common.IntegrationData\"\x8b\x01\n\x0fListJobsRequest\x12&\n\tauth_info\x18\x01 \x01(\x0b\x32\x13.common.NBXAuthInfo\x12\r\n\x05limit\x18\x02 \x01(\x05\x12\x0e\n\x06offset\x18\x03 \x01(\x05\x12\x31\n\x10integration_data\x18\x04 \x01(\x0b\x32\x17.common.IntegrationData\">\n\x10ListJobsResponse\x12\x17\n\x04jobs\x18\x01 \x03(\x0b\x32\t.jobs.Job\x12\x11\n\tnext_page\x18\x02 \x01(\x05\"\xd5\x01\n\x10UpdateRunRequest\x12\r\n\x05token\x18\x01 \x01(\t\x12\x16\n\x03job\x18\x02 \x01(\x0b\x32\t.jobs.Job\x12.\n\nupdated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07message\x18\x04 \x01(\t\x12&\n\tauth_info\x18\x05 \x01(\x0b\x32\x13.common.NBXAuthInfo\x12\x31\n\x10integration_data\x18\x06 \x01(\x0b\x32\x17.common.IntegrationData2\xcb\x04\n\x0cWSJobService\x12*\n\x06GetJob\x12\x13.jobs.ws.JobRequest\x1a\t.jobs.Job\"\x00\x12\x41\n\x08ListJobs\x12\x18.jobs.ws.ListJobsRequest\x1a\x19.jobs.ws.ListJobsResponse\"\x00\x12\x31\n\rUploadJobCode\x12\x13.jobs.ws.JobRequest\x1a\t.jobs.Job\"\x00\x12-\n\tCreateJob\x12\x13.jobs.ws.JobRequest\x1a\t.jobs.Job\"\x00\x12\x33\n\tUpdateJob\x12\x19.jobs.ws.UpdateJobRequest\x1a\t.jobs.Job\"\x00\x12:\n\tDeleteJob\x12\x13.jobs.ws.JobRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x32\n\nGetJobLogs\x12\x13.jobs.ws.JobRequest\x1a\x0b.common.Log\"\x00\x30\x01\x12?\n\nTriggerJob\x12\x13.jobs.ws.JobRequest\x1a\x1a.google.protobuf.BoolValue\"\x00\x12@\n\tUpdateRun\x12\x19.jobs.ws.UpdateRunRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x42\n\x0bGetRunToken\x12\x13.jobs.ws.JobRequest\x1a\x1c.google.protobuf.StringValue\"\x00\x42=Z;github.com/NimbleBoxAI/jobs-architecture/jobs_pb/v3;jobs_pbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'jobs.nbox_ws_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z;github.com/NimbleBoxAI/jobs-architecture/jobs_pb/v3;jobs_pb'
  _JOBREQUEST._serialized_start=196
  _JOBREQUEST._serialized_end=323
  _UPDATEJOBREQUEST._serialized_start=326
  _UPDATEJOBREQUEST._serialized_end=508
  _LISTJOBSREQUEST._serialized_start=511
  _LISTJOBSREQUEST._serialized_end=650
  _LISTJOBSRESPONSE._serialized_start=652
  _LISTJOBSRESPONSE._serialized_end=714
  _UPDATERUNREQUEST._serialized_start=717
  _UPDATERUNREQUEST._serialized_end=930
  _WSJOBSERVICE._serialized_start=933
  _WSJOBSERVICE._serialized_end=1520
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class HandshakeRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    JWT_FIELD_NUMBER: builtins.int
    INSTANCEKEY_FIELD_NUMBER: builtins.int
    LAUNCHURL_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    jwt: typing.Text
    instanceKey: typing.Text
    launchURL: typing.Text
    port: typing.Text
    def __init__(self,
        *,
        jwt: typing.Text = ...,
        instanceKey: typing.Text = ...,
        launchURL: typing.Text = ...,
        port: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["instanceKey",b"instanceKey","jwt",b"jwt","launchURL",b"launchURL","port",b"port"]) -> None: ...
global___HandshakeRequest = HandshakeRequest

class HandshakeResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TOKEN_FIELD_NUMBER: builtins.int
    token: typing.Text
    def __init__(self,
        *,
        token: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["token",b"token"]) -> None: ...
global___HandshakeResponse = HandshakeResponse

class DataPacket(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TOKEN_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    token: typing.Text
    data: builtins.bytes
    def __init__(self,
        *,
        token: typing.Text = ...,
        data: builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data",b"data","token",b"token"]) -> None: ...
global___DataPacket = DataPacket



"""
Though initially this code just like the `on_ml.py <nbox.framework.on_ml.html>`_
code was build separately for each different package that we supported and that
led to just some really duct taping and hacking around that made it inefficient
to scale. The lesson is that premature attempts to scale are as bad as not being
able to scale. On that end eventually this file will be broken apart by packages
but hopefully it is in a way better. My depth limit = 2.

Read the code for best understanding.
"""

import inspect # used for __doc__
from functools import partial
from datetime import timedelta
from nbox.utils import isthere, logger


################################################################################
# Airflow
# =======
# Airflow is a great tool, but, read this
# https://nimblebox.notion.site/Control-Flow-vs-Data-Flow-332916c53b7f4a42a0b37d6aa365d4b7
################################################################################

class AirflowMixin:
  @isthere("airflow", soft = False)
  def nbx_job_to_airflow_operator(job, timeout: timedelta = None, operator_kwargs = {}):
    """
    Args:
      operator (Operator): nbox.Operator object to be converted to Airflow Operator
      timeout (timedelta, default=None): in how many seconds the operator should timeout
    """
    operator_kwargs_dict = {}
    operator_kwargs_dict["execution_timeout"] = timeout
    operator_kwargs_dict["sla"] = timeout
    operator_kwargs_dict["task_id"] = operator.__class__.__name__

    try:
      comms = operator.comms()
    except:
      comms = {}

    # this is currently assumed to be rst text because this is what we are using
    # for documentation at NBX
    doc = operator.__doc__ # this is in between class xxx and def __init__
    doc = doc if doc else ""
    init_doc = inspect.getdoc(operator.__init__) # this is doc for __init__
    init_doc = init_doc if init_doc else ""
    full_doc = doc + "\n" + init_doc
    full_doc = None if not full_doc else full_doc
    operator_kwargs_dict["doc_rst"] = full_doc

    # update the dict with information
    operator_kwargs_dict.update(comms)
    operator_kwargs_dict.update(operator_kwargs)

    # importing inside the function  
    from airflow.models.baseoperator import BaseOperator
    from ..init import reset_log
    reset_log()

    operator = BaseOperator(
      # items planned to be supported
      email = None,
      email_on_retry = False,
      email_on_failure = False,
      
      # documentation to be handled, currently assumed to be rst documentation
      doc = None,
      doc_md = None,
      doc_json = None,
      doc_yaml = None,

      # these can be the hooks that user defines for Operators
      # ie. is the airflow.operator executes user defines which of
      # their functions to call
      on_execute_callback = None,
      on_failure_callback = None,
      on_success_callback = None,
      on_retry_callback = None,

      # others are ignored as of now
      **operator_kwargs_dict
    )

    return operator


################################################################################
# Prefect
# =======
# https://github.com/PrefectHQ/prefect
################################################################################

class PrefectMixin:
  @classmethod
  def from_prefect_flow(operator_cls, dag):
    raise NotImplementedError
  
  def to_prefect_flow():
    raise NotImplementedError

  @classmethod
  def from_prefect_task(operator_cls, dag):
    raise NotImplementedError

  def to_prefect_task():
    raise NotImplementedError





"""
This is the code for NBX-Relics which is a simple file system for your organisation.
"""
import os
import time
import json
import cloudpickle
import requests
import tabulate
from hashlib import md5
from typing import List
from copy import deepcopy
from subprocess import Popen
from functools import lru_cache

from nbox.auth import secret
from nbox.init import nbox_ws_v1
from nbox.messages import message_to_dict
from nbox.utils import logger, env, get_mime_type
from nbox.sublime.relics_rpc_client import (
  RelicStore_Stub,
  RelicFile,
  Relic as RelicProto,
  CreateRelicRequest,
  ListRelicFilesRequest,
  ListRelicsRequest,
  BucketMetadata
)
from nbox.relics.base import BaseStore
from nbox.auth import ConfigString, secret

def get_relic_file(fpath: str, username: str, workspace_id: str = ""):
  workspace_id = workspace_id or secret.get(ConfigString.workspace_id)
  # assert os.path.exists(fpath), f"File {fpath} does not exist"
  # assert os.path.isfile(fpath), f"File {fpath} is not a file"

  # clean up fpath, remove any trailing slashes
  # trim any . or / from prefix and suffix
  fpath_cleaned = fpath.strip("./")

  extra = {}
  if os.path.exists(fpath):
    file_stat = os.stat(fpath)
    extra = {
      "created_on": int(file_stat.st_mtime),    # int
      "last_modified": int(file_stat.st_mtime), # int
      "size": max(1, file_stat.st_size),        # bytes
    }

  if "." in fpath_cleaned:
    content_type = get_mime_type(fpath_cleaned.split(".")[-1], "application/octet-stream")
  else:
    content_type = "application/octet-stream"

  return RelicFile(
    name = fpath_cleaned,
    username = username,
    type = RelicFile.RelicType.FILE,
    workspace_id = workspace_id,
    content_type=content_type,
    **extra
  )


@lru_cache()
def _get_stub():
  # url = "http://0.0.0.0:8081/relics" # debug mode
  url = secret.get("nbx_url") + "/relics"
  logger.debug("Connecting to RelicStore at: " + url)
  session = deepcopy(nbox_ws_v1._session)
  stub = RelicStore_Stub(url, session)
  return stub


def print_relics(workspace_id: str = ""):
  stub = _get_stub()
  workspace_id = workspace_id or secret.get(ConfigString.workspace_id)
  req = ListRelicsRequest(workspace_id = workspace_id,)
  out = stub.list_relics(req)
  headers = ["relic_id", "relic_name",]
  rows = [[r.id, r.name,] for r in out.relics]
  for l in tabulate.tabulate(rows, headers).splitlines():
    logger.info(l)



class UserAgentType:
  PYTHON_REQUESTS = "python-requests"
  CURL = "curl"

  def all():
    return [UserAgentType.PYTHON_REQUESTS, UserAgentType.CURL,]


class RelicsNBX(BaseStore):
  list = staticmethod(print_relics)

  def __init__(
    self,
    relic_name: str,
    workspace_id: str = "",
    create: bool = False,
    prefix: str = "",
    *,
    bucket_name: str = "",
    region: str = "",
    nbx_resource_id: str = "",
    nbx_integration_token: str = "",
  ):
    """
    The client for NBX-Relics. Auto switches to different user/agents for upload download

    Args:
      relic_name (str): The name of the relic.
      workspace_id (str): The workspace ID, if not provided, will be one in global config.
      create (bool): Create the relic if it does not exist.
      prefix (str): The prefix to use for all files in this relic. If provided all the files are uploaded and downloaded with this prefix.
    """
    self.workspace_id = workspace_id or secret.get(ConfigString.workspace_id)
    self.relic_name = relic_name
    self.username = secret.get("username") # if its in the job then this part will automatically be filled
    self.prefix = prefix.strip("/")
    self.stub = _get_stub()
    for _ in range(2):
      _relic = self.stub.get_relic_details(RelicProto(workspace_id=self.workspace_id, name=relic_name,))
      if _relic != None:
        break
      time.sleep(1)

    # print("asdfasdfasdfasdf", _relic, not _relic and create)
    if not _relic and create:
      # this means that a new one will have to be created
      logger.debug(f"Creating new relic {relic_name}")
      self.relic = self.stub.create_relic(CreateRelicRequest(
        workspace_id=self.workspace_id,
        name = relic_name,
        bucket_meta = BucketMetadata(
          bucket_name = bucket_name,
          region = region,
          backend = BucketMetadata.Backend.AWS_S3,
        ),
        nbx_resource_id = nbx_resource_id,
        nbx_integration_token = nbx_integration_token,
      ))
      logger.debug(f"Created new relic {self.relic}")
    else:
      self.relic = _relic
    
    self.uat = UserAgentType.PYTHON_REQUESTS

  
  def set_user_agent(self, user_agent_type: str):
    if user_agent_type not in UserAgentType.all():
      raise ValueError(f"Invalid user agent type: {user_agent_type}")
    logger.info(f"Setting user agent to {user_agent_type} from {self.uat}")
    self.uat = user_agent_type

  def __repr__(self):
    return f"RelicStore({self.workspace_id}, {self.relic_name}, {'CONNECTED' if self.relic else 'NOT CONNECTED'})"

  def _upload_relic_file(self, local_path: str, relic_file: RelicFile):
    if not relic_file.relic_name:
      raise ValueError("relic_name not set in RelicFile")
    if self.prefix:
      relic_file.name = f"{self.prefix}/{relic_file.name}"

    # ideally this is a lot like what happens in nbox
    logger.info(f"Uploading {local_path} to {relic_file.name}")
    for _ in range(2):
      out = self.stub.create_file(_RelicFile = relic_file,)
      if out != None:
        break
      time.sleep(1)

    if not out.url:
      raise Exception("Could not get link")

    # do merge 'out' and 'relic_file' here because "url" might get stored in MongoDB
    # relic_file.MergeFrom(out)
    ten_mb = 10 ** 7
    uat = self.uat
    old_uat = uat
    if out.size > ten_mb:
      logger.warning(f"File {local_path} is larger than 10 MiB ({out.size} bytes), this might take a while")
      logger.warning(f"Switching to user/agent: cURL for this upload")
      uat = UserAgentType.CURL

    if uat == UserAgentType.PYTHON_REQUESTS:
      logger.debug(f"URL: {out.url}")
      logger.debug(f"body: {out.body}")
      r = requests.post(
        url = out.url,
        data = out.body,
        files = {"file": (out.body["key"], open(local_path, "rb"))}
      )
      logger.info(f"Upload status: {r.status_code}")
      r.raise_for_status()
    elif uat == UserAgentType.CURL:
      # TIL: https://stackoverflow.com/a/58237351
      # the fields in the post can be sent in any order

      import shlex
      shell_com = f'curl -X POST -F key={out.body["key"]} '
      for k,v in out.body.items():
        if k == "key":
          continue
        shell_com += f'-F {k}={v} '
      shell_com += f'-F file="@{local_path}" {out.url}'
      logger.debug(f"Running shell command: {shell_com}")
      Popen(shlex.split(shell_com)).wait()

    if old_uat != uat:
      logger.warning(f"Restoring user/agent to {old_uat}")
      self.set_user_agent(old_uat)


  def _download_relic_file(self, local_path: str, relic_file: RelicFile):
    if self.relic is None:
      raise ValueError("Relic does not exist, pass create=True")
    if self.prefix:
      relic_file.name = self.prefix + "/" + relic_file.name

    # ideally this is a lot like what happens in nbox
    logger.debug(f"Downloading {local_path} from S3 ...")
    for _ in range(2):
      out = self.stub.download_file(_RelicFile = relic_file,)
      if out != None:
        break
      time.sleep(1)

    if not out.url:
      raise Exception("Could not get link, are you sure this file exists?")

    # same logic as in upload but for download
    ten_mb = 10 ** 7
    uat = self.uat
    if out.size > ten_mb:
      logger.warning(f"File {local_path} is larger than 10 MiB ({out.size} bytes), this might take a while")
      logger.warning(f"Switching to user/agent: cURL for this download")
      uat = UserAgentType.CURL

    if uat == UserAgentType.PYTHON_REQUESTS:    
      # do not perform merge here because "url" might get stored in MongoDB
      # relic_file.MergeFrom(out)
      logger.debug(f"URL: {out.url}")
      with requests.get(out.url, stream=True) as r:
        r.raise_for_status()
        total_size = 0
        with open(local_path, 'wb') as f:
          for chunk in r.iter_content(chunk_size=8192): 
            # If you have chunk encoded response uncomment if
            # and set chunk_size parameter to None.
            #if chunk: 
            f.write(chunk)
            total_size += len(chunk)
    elif uat == UserAgentType.CURL:
      import shlex
      shell_com = f'curl -o {local_path} {out.url}'
      logger.debug(f"Running shell command: {shell_com}")
      Popen(shlex.split(shell_com)).wait()
      total_size = os.path.getsize(local_path)
    logger.debug(f"Download '{local_path}' status: OK ({total_size//1000} KiB)")

  """
  At it's core the Relic is supposed to be a file system and not a client. Thus you cannot download something
  from a relic, but rather you tell the path you want to read and it will return the file. This is because of the
  fact that this is nothing but a glorified key value store.

  Moreover Relic as a broader concept is a storage in Von Neumann architecture. It is a storage that is not, so
  the more ways to store files built into it, the better the experience. So there are different types of put and
  get methods.
  """

  def put(self, local_path: str):
    """Put the file at this path into the relic"""
    if self.relic is None:
      raise ValueError("Relic does not exist, pass create=True")
    logger.debug(f"Putting file: {local_path}")
    relic_file = get_relic_file(local_path, self.username, self.workspace_id)
    relic_file.relic_name = self.relic_name
    self._upload_relic_file(local_path, relic_file)

  def put_to(self, local_path: str, remote_path: str) -> None:
    if self.relic is None:
      raise ValueError("Relic does not exist, pass create=True")
    logger.debug(f"Putting file: {local_path} to {remote_path}")
    relic_file = get_relic_file(local_path, self.username, self.workspace_id)
    relic_file.relic_name = self.relic_name
    relic_file.name = remote_path # override the name
    self._upload_relic_file(local_path, relic_file)

  def get(self, local_path: str):
    """Get the file at this path from the relic"""
    if self.relic is None:
      raise ValueError("Relic does not exist, pass create=True")
    logger.debug(f"Getting file: {local_path}")
    relic_file = RelicFile(name = local_path.strip("./"),)
    relic_file.relic_name = self.relic_name
    relic_file.workspace_id = self.workspace_id
    self._download_relic_file(local_path, relic_file)

  def get_from(self, local_path: str, remote_path: str, unzip: bool = False) -> None:
    # TODO:@yashbonde add support for unzipping
    if self.relic is None:
      raise ValueError("Relic does not exist, pass create=True")
    logger.debug(f"Getting file: {local_path} from {remote_path}")
    relic_file = RelicFile(name = remote_path.strip("./"),)
    relic_file.relic_name = self.relic_name
    relic_file.workspace_id = self.workspace_id
    self._download_relic_file(local_path, relic_file)

  def rm(self, remote_path: str):
    """Delete the file at this path from the relic"""
    if self.relic is None:
      raise ValueError("Relic does not exist, pass create=True")
    logger.debug(f"Getting file: {remote_path}")
    relic_file = get_relic_file(remote_path, self.username, self.workspace_id)
    relic_file.relic_name = self.relic_name
    for _ in range(2):
      out = self.stub.delete_relic_file(relic_file)
      if out != None:
        break
      time.sleep(1)
    
    if not out.success:
      logger.error(out.message)
      raise ValueError("Could not delete file")

  def has(self, path: str):
    prefix, file_name = os.path.split(path)
    for _ in range(2):
      out = self.stub.list_relic_files(
        ListRelicFilesRequest(
          workspace_id=self.workspace_id,
          relic_name=self.relic_name,
          prefix=prefix,
          file_name=file_name
        )
      )
      if out != None:
        break
      time.sleep(1)

    for f in out.files:
      if f.name.strip("/") == path.strip("/"):
        return True
    return False


  """
  There are other convinience methods provided to keep consistency between the different types of relics. Note
  that we do no have a baseclass right now because I am note sure what are all the possible features we can have
  in common with all.
  """

  def put_object(self, key: str, py_object):
    """wrapper function for putting a python object"""
    # we will cache the object in the local file system
    cache_dir = os.path.join(env.NBOX_HOME_DIR(), ".cache")
    if not os.path.exists(cache_dir):
      os.makedirs(cache_dir)
    _key = os.path.join(cache_dir, md5(key.encode()).hexdigest())
    with open(_key, "wb") as f:
      cloudpickle.dump(py_object, f)
    self.put_to(_key, key)

  def get_object(self, key: str):
    """wrapper function for getting a python object"""
    cache_dir = os.path.join(env.NBOX_HOME_DIR(), ".cache")
    if not os.path.exists(cache_dir):
      os.makedirs(cache_dir)
    _key = os.path.join(cache_dir, md5(key.encode()).hexdigest())
    self.get_from(_key, key)
    with open(_key, "rb") as f:
      out = cloudpickle.load(f)
    return out

  """
  Some APIs are more on the level of the relic itself.
  """

  def delete(self):
    """Deletes your relic"""
    if self.relic is None:
      raise ValueError("Relic does not exist, nothing to delete")
    logger.warning(f"Deleting relic {self.relic_name}")
    self.stub.delete_relic(self.relic)

  def list_files(self, path: str = "") -> List[RelicFile]:
    """List all the files in the relic at path"""
    if self.relic is None:
      raise ValueError("Relic does not exist, pass create=True")
    logger.debug(f"Listing files in relic {self.relic_name}")
    out = self.stub.list_relic_files(RelicFile(
      workspace_id = self.workspace_id,
      relic_name = self.relic_name,
      name = path
    ))
    return out.files

  def start_fs():
    # /my_relic/.....
    pass

# nbx jobs ... trigger --mount="dataset:/my-dataset/email/,model_master:/model"



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class LogBuffer(google.protobuf.message.Message):
    """since this is becoming a more serious thing than what we initially were building we need to make it
    more production ready and the first step is to log a buffer object instead of the individual log object.
    we create a message called LogBuffer which is nothing but an array of _LogObject which in turn is
    either a RunLog or a LiveLog object.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    AGENT_TOKEN_FIELD_NUMBER: builtins.int
    RUN_LOGS_FIELD_NUMBER: builtins.int
    LIVE_LOGS_FIELD_NUMBER: builtins.int
    agent_token: typing.Text
    """this is like the experiment_id in runs where an agent tries to connect and server gives it a
    one time token with which all the incoming logs will be identified with
    """

    @property
    def run_logs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RunLog]:
        """this can either contain one or the other"""
        pass
    @property
    def live_logs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServingHTTPLog]: ...
    def __init__(self,
        *,
        agent_token: typing.Text = ...,
        run_logs: typing.Optional[typing.Iterable[global___RunLog]] = ...,
        live_logs: typing.Optional[typing.Iterable[global___ServingHTTPLog]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["agent_token",b"agent_token","live_logs",b"live_logs","run_logs",b"run_logs"]) -> None: ...
global___LogBuffer = LogBuffer

class ServingHTTPLog(google.protobuf.message.Message):
    """LiveLog is an individual call event which is created by the user agent whenever a certain API is called.
    it contains some basic information as in any other general monitoring solution.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PATH_FIELD_NUMBER: builtins.int
    METHOD_FIELD_NUMBER: builtins.int
    STATUS_CODE_FIELD_NUMBER: builtins.int
    LATENCY_MS_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    path: typing.Text
    """the endpoint ie. /api/monitoring/"""

    method: typing.Text
    """the method ie. GET, POST, PUT, DELETE"""

    status_code: builtins.int
    """the status code ie. 200, 404, 500"""

    latency_ms: builtins.float
    """the latency in milli-seconds"""

    @property
    def timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """the timestamp when this event was created"""
        pass
    def __init__(self,
        *,
        path: typing.Text = ...,
        method: typing.Text = ...,
        status_code: builtins.int = ...,
        latency_ms: builtins.float = ...,
        timestamp: typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["timestamp",b"timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["latency_ms",b"latency_ms","method",b"method","path",b"path","status_code",b"status_code","timestamp",b"timestamp"]) -> None: ...
global___ServingHTTPLog = ServingHTTPLog

class ListDeploymentsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    WORKSPACE_ID_FIELD_NUMBER: builtins.int
    SERVING_ID_OR_NAME_FIELD_NUMBER: builtins.int
    PAGE_NO_FIELD_NUMBER: builtins.int
    workspace_id: typing.Text
    serving_id_or_name: typing.Text
    """used specifically for searching, if empty, it will return all the projects"""

    page_no: builtins.int
    def __init__(self,
        *,
        workspace_id: typing.Text = ...,
        serving_id_or_name: typing.Text = ...,
        page_no: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["page_no",b"page_no","serving_id_or_name",b"serving_id_or_name","workspace_id",b"workspace_id"]) -> None: ...
global___ListDeploymentsRequest = ListDeploymentsRequest

class ListDeploymentsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class Serving(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        SERVING_ID_FIELD_NUMBER: builtins.int
        SERVING_NAME_FIELD_NUMBER: builtins.int
        TOTAL_MODELS_FIELD_NUMBER: builtins.int
        serving_id: typing.Text
        """the unique ID for this serving"""

        serving_name: typing.Text
        """the usermodifiable name of the serving"""

        total_models: builtins.int
        """the total number of models in this serving group"""

        def __init__(self,
            *,
            serving_id: typing.Text = ...,
            serving_name: typing.Text = ...,
            total_models: builtins.int = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["serving_id",b"serving_id","serving_name",b"serving_name","total_models",b"total_models"]) -> None: ...

    WORKSPACE_ID_FIELD_NUMBER: builtins.int
    SERVING_FIELD_NUMBER: builtins.int
    TOTAL_PAGES_FIELD_NUMBER: builtins.int
    workspace_id: typing.Text
    @property
    def serving(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ListDeploymentsResponse.Serving]: ...
    total_pages: builtins.int
    def __init__(self,
        *,
        workspace_id: typing.Text = ...,
        serving: typing.Optional[typing.Iterable[global___ListDeploymentsResponse.Serving]] = ...,
        total_pages: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["serving",b"serving","total_pages",b"total_pages","workspace_id",b"workspace_id"]) -> None: ...
global___ListDeploymentsResponse = ListDeploymentsResponse

class ListServingsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    WORKSPACE_ID_FIELD_NUMBER: builtins.int
    DEPLOYMENT_ID_FIELD_NUMBER: builtins.int
    RUN_ID_FIELD_NUMBER: builtins.int
    PAGE_NO_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    workspace_id: typing.Text
    """the workspace this is part of"""

    deployment_id: typing.Text
    """the unique ID for this project"""

    run_id: typing.Text
    """for searching"""

    page_no: builtins.int
    desc: builtins.bool
    def __init__(self,
        *,
        workspace_id: typing.Text = ...,
        deployment_id: typing.Text = ...,
        run_id: typing.Text = ...,
        page_no: builtins.int = ...,
        desc: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["deployment_id",b"deployment_id","desc",b"desc","page_no",b"page_no","run_id",b"run_id","workspace_id",b"workspace_id"]) -> None: ...
global___ListServingsRequest = ListServingsRequest

class ListServingsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MODEL_IDS_FIELD_NUMBER: builtins.int
    KEYS_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    TOTAL_PAGES_FIELD_NUMBER: builtins.int
    @property
    def model_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]:
        """the list of runs in this project"""
        pass
    @property
    def keys(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]:
        """the list of chart-keys for this run"""
        pass
    @property
    def created_at(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]:
        """time when these runs were created"""
        pass
    total_pages: builtins.int
    """the total number of pages"""

    def __init__(self,
        *,
        model_ids: typing.Optional[typing.Iterable[typing.Text]] = ...,
        keys: typing.Optional[typing.Iterable[typing.Text]] = ...,
        created_at: typing.Optional[typing.Iterable[builtins.int]] = ...,
        total_pages: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["created_at",b"created_at","keys",b"keys","model_ids",b"model_ids","total_pages",b"total_pages"]) -> None: ...
global___ListServingsResponse = ListServingsResponse

class Serving(google.protobuf.message.Message):
    """the Big Serving Object"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class _Status:
        ValueType = typing.NewType('ValueType', builtins.int)
        V: typing_extensions.TypeAlias = ValueType
    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Serving._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        NOT_SET: Serving._Status.ValueType  # 0
        """When created and added to DB but no further action taken"""

        RUNNING: Serving._Status.ValueType  # 1
        """When the first on_serving_log has been called"""

        COMPLETED: Serving._Status.ValueType  # 2
        """When there is a graceful exit on_serving_end has been called"""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper):
        pass

    NOT_SET: Serving.Status.ValueType  # 0
    """When created and added to DB but no further action taken"""

    RUNNING: Serving.Status.ValueType  # 1
    """When the first on_serving_log has been called"""

    COMPLETED: Serving.Status.ValueType  # 2
    """When there is a graceful exit on_serving_end has been called"""


    WORKSPACE_ID_FIELD_NUMBER: builtins.int
    AGENT_FIELD_NUMBER: builtins.int
    AGENT_TOKEN_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    UPDATED_AT_FIELD_NUMBER: builtins.int
    workspace_id: typing.Text
    @property
    def agent(self) -> global___AgentDetails:
        """the agent details"""
        pass
    agent_token: typing.Text
    """the unique ID of this agent from the MongoDB backend"""

    created_at: builtins.int
    """same as InitRunRequest.created_at"""

    config: typing.Text
    """the jsonified config string"""

    status: global___Serving.Status.ValueType
    """the last known status of this run"""

    updated_at: builtins.int
    """the last time this"""

    def __init__(self,
        *,
        workspace_id: typing.Text = ...,
        agent: typing.Optional[global___AgentDetails] = ...,
        agent_token: typing.Text = ...,
        created_at: builtins.int = ...,
        config: typing.Text = ...,
        status: global___Serving.Status.ValueType = ...,
        updated_at: builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["agent",b"agent"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["agent",b"agent","agent_token",b"agent_token","config",b"config","created_at",b"created_at","status",b"status","updated_at",b"updated_at","workspace_id",b"workspace_id"]) -> None: ...
global___Serving = Serving

class Record(google.protobuf.message.Message):
    """This is the data that the user will be logging if this"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class _DataType:
        ValueType = typing.NewType('ValueType', builtins.int)
        V: typing_extensions.TypeAlias = ValueType
    class _DataTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Record._DataType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        FLOAT: Record._DataType.ValueType  # 0
        INTEGER: Record._DataType.ValueType  # 1
        STRING: Record._DataType.ValueType  # 2
    class DataType(_DataType, metaclass=_DataTypeEnumTypeWrapper):
        """since it is not possible to have the map in the message, we need to have an enum for the target datatype"""
        pass

    FLOAT: Record.DataType.ValueType  # 0
    INTEGER: Record.DataType.ValueType  # 1
    STRING: Record.DataType.ValueType  # 2

    KEY_FIELD_NUMBER: builtins.int
    VALUE_TYPE_FIELD_NUMBER: builtins.int
    STEP_FIELD_NUMBER: builtins.int
    FLOAT_DATA_FIELD_NUMBER: builtins.int
    INTEGER_DATA_FIELD_NUMBER: builtins.int
    STRING_DATA_FIELD_NUMBER: builtins.int
    key: typing.Text
    """name of this data"""

    value_type: global___Record.DataType.ValueType
    step: builtins.int
    """also can be called "X-axis" or just x"""

    @property
    def float_data(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]:
        """all the data is done in the"""
        pass
    @property
    def integer_data(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    @property
    def string_data(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...
    def __init__(self,
        *,
        key: typing.Text = ...,
        value_type: global___Record.DataType.ValueType = ...,
        step: builtins.int = ...,
        float_data: typing.Optional[typing.Iterable[builtins.float]] = ...,
        integer_data: typing.Optional[typing.Iterable[builtins.int]] = ...,
        string_data: typing.Optional[typing.Iterable[typing.Text]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["float_data",b"float_data","integer_data",b"integer_data","key",b"key","step",b"step","string_data",b"string_data","value_type",b"value_type"]) -> None: ...
global___Record = Record

class RecordColumn(google.protobuf.message.Message):
    """RecordColumn should be the main key:value(s) thing we are going to use it for both the charts and scalar data."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class _DataType:
        ValueType = typing.NewType('ValueType', builtins.int)
        V: typing_extensions.TypeAlias = ValueType
    class _DataTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[RecordColumn._DataType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        FLOAT: RecordColumn._DataType.ValueType  # 0
        INTEGER: RecordColumn._DataType.ValueType  # 1
        STRING: RecordColumn._DataType.ValueType  # 2
    class DataType(_DataType, metaclass=_DataTypeEnumTypeWrapper):
        """type of this data"""
        pass

    FLOAT: RecordColumn.DataType.ValueType  # 0
    INTEGER: RecordColumn.DataType.ValueType  # 1
    STRING: RecordColumn.DataType.ValueType  # 2

    class RecordRow(google.protobuf.message.Message):
        """the actual data"""
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        X_FIELD_NUMBER: builtins.int
        FLOAT_DATA_FIELD_NUMBER: builtins.int
        INTEGER_DATA_FIELD_NUMBER: builtins.int
        STRING_DATA_FIELD_NUMBER: builtins.int
        x: builtins.int
        """also can be called "X-axis" or just x"""

        float_data: builtins.float
        """all the data is done in the"""

        integer_data: builtins.int
        string_data: typing.Text
        def __init__(self,
            *,
            x: builtins.int = ...,
            float_data: builtins.float = ...,
            integer_data: builtins.int = ...,
            string_data: typing.Text = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["float_data",b"float_data","integer_data",b"integer_data","string_data",b"string_data","x",b"x"]) -> None: ...

    KEY_FIELD_NUMBER: builtins.int
    VALUE_TYPE_FIELD_NUMBER: builtins.int
    ROWS_FIELD_NUMBER: builtins.int
    key: typing.Text
    """since it is not possible to have the map in the message, we need to have an enum for the target datatype
    name of this data
    """

    value_type: global___RecordColumn.DataType.ValueType
    @property
    def rows(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RecordColumn.RecordRow]:
        """give me all the values for a given column (key), so in case of table, we can simply say that
        we are returning only one value for each column ie. len(RecordColumn.rows) == 1
        this is similar to saying bar chart value, it will be a scalar but wrapped as a array of length one
        """
        pass
    def __init__(self,
        *,
        key: typing.Text = ...,
        value_type: global___RecordColumn.DataType.ValueType = ...,
        rows: typing.Optional[typing.Iterable[global___RecordColumn.RecordRow]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key",b"key","rows",b"rows","value_type",b"value_type"]) -> None: ...
global___RecordColumn = RecordColumn

class RunLog(google.protobuf.message.Message):
    """This is the aggregation of all the logs for this run"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class _LogType:
        ValueType = typing.NewType('ValueType', builtins.int)
        V: typing_extensions.TypeAlias = ValueType
    class _LogTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[RunLog._LogType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        SYSTEM: RunLog._LogType.ValueType  # 0
        """these are the mtrics like GPU/RAM utilisation"""

        NBX: RunLog._LogType.ValueType  # 1
        """these are the metrics that NimbleBox generates for the user"""

        USER: RunLog._LogType.ValueType  # 2
        """these are the metrics that the user has logged"""

    class LogType(_LogType, metaclass=_LogTypeEnumTypeWrapper):
        pass

    SYSTEM: RunLog.LogType.ValueType  # 0
    """these are the mtrics like GPU/RAM utilisation"""

    NBX: RunLog.LogType.ValueType  # 1
    """these are the metrics that NimbleBox generates for the user"""

    USER: RunLog.LogType.ValueType  # 2
    """these are the metrics that the user has logged"""


    EXPERIMENT_ID_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    COLUMN_DATA_FIELD_NUMBER: builtins.int
    LOG_TYPE_FIELD_NUMBER: builtins.int
    PROJECT_ID_FIELD_NUMBER: builtins.int
    WORKSPACE_ID_FIELD_NUMBER: builtins.int
    experiment_id: typing.Text
    @property
    def data(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Record]:
        """TODO: @yashbonde deprecate this"""
        pass
    @property
    def column_data(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RecordColumn]:
        """this is the chart wise data"""
        pass
    log_type: global___RunLog.LogType.ValueType
    """type of data"""

    project_id: typing.Text
    """project id"""

    workspace_id: typing.Text
    """workspace id"""

    def __init__(self,
        *,
        experiment_id: typing.Text = ...,
        data: typing.Optional[typing.Iterable[global___Record]] = ...,
        column_data: typing.Optional[typing.Iterable[global___RecordColumn]] = ...,
        log_type: global___RunLog.LogType.ValueType = ...,
        project_id: typing.Text = ...,
        workspace_id: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["column_data",b"column_data","data",b"data","experiment_id",b"experiment_id","log_type",b"log_type","project_id",b"project_id","workspace_id",b"workspace_id"]) -> None: ...
global___RunLog = RunLog

class AgentDetails(google.protobuf.message.Message):
    """all the NBX-Infra details for this specific process"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class _NBX:
        ValueType = typing.NewType('ValueType', builtins.int)
        V: typing_extensions.TypeAlias = ValueType
    class _NBXEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[AgentDetails._NBX.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        JOB: AgentDetails._NBX.ValueType  # 0
        SERVING: AgentDetails._NBX.ValueType  # 1
    class NBX(_NBX, metaclass=_NBXEnumTypeWrapper):
        pass

    JOB: AgentDetails.NBX.ValueType  # 0
    SERVING: AgentDetails.NBX.ValueType  # 1

    WORKSPACE_ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    NBX_JOB_ID_FIELD_NUMBER: builtins.int
    NBX_SERVING_ID_FIELD_NUMBER: builtins.int
    NBX_RUN_ID_FIELD_NUMBER: builtins.int
    NBX_MODEL_ID_FIELD_NUMBER: builtins.int
    workspace_id: typing.Text
    type: global___AgentDetails.NBX.ValueType
    """this is the type of the agent, JOB or SERVING"""

    nbx_job_id: typing.Text
    """NBX-Jobs ID"""

    nbx_serving_id: typing.Text
    """deployment id"""

    nbx_run_id: typing.Text
    """JobRun"""

    nbx_model_id: typing.Text
    """model id"""

    def __init__(self,
        *,
        workspace_id: typing.Text = ...,
        type: global___AgentDetails.NBX.ValueType = ...,
        nbx_job_id: typing.Text = ...,
        nbx_serving_id: typing.Text = ...,
        nbx_run_id: typing.Text = ...,
        nbx_model_id: typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["id",b"id","instance",b"instance","nbx_job_id",b"nbx_job_id","nbx_model_id",b"nbx_model_id","nbx_run_id",b"nbx_run_id","nbx_serving_id",b"nbx_serving_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id",b"id","instance",b"instance","nbx_job_id",b"nbx_job_id","nbx_model_id",b"nbx_model_id","nbx_run_id",b"nbx_run_id","nbx_serving_id",b"nbx_serving_id","type",b"type","workspace_id",b"workspace_id"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["id",b"id"]) -> typing.Optional[typing_extensions.Literal["nbx_job_id","nbx_serving_id"]]: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["instance",b"instance"]) -> typing.Optional[typing_extensions.Literal["nbx_run_id","nbx_model_id"]]: ...
global___AgentDetails = AgentDetails

class InitRunRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    WORKSPACE_ID_FIELD_NUMBER: builtins.int
    PROJECT_ID_FIELD_NUMBER: builtins.int
    PROJECT_NAME_FIELD_NUMBER: builtins.int
    AGENT_DETAILS_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    workspace_id: typing.Text
    """when this is an experiment we will have project details"""

    project_id: typing.Text
    project_name: typing.Text
    @property
    def agent_details(self) -> global___AgentDetails: ...
    config: typing.Text
    """the jsonified singular config string"""

    def __init__(self,
        *,
        workspace_id: typing.Text = ...,
        project_id: typing.Text = ...,
        project_name: typing.Text = ...,
        agent_details: typing.Optional[global___AgentDetails] = ...,
        config: typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["agent_details",b"agent_details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["agent_details",b"agent_details","config",b"config","project_id",b"project_id","project_name",b"project_name","workspace_id",b"workspace_id"]) -> None: ...
global___InitRunRequest = InitRunRequest

class File(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    NAME_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    IS_INPUT_FIELD_NUMBER: builtins.int
    RELIC_KEY_FIELD_NUMBER: builtins.int
    name: typing.Text
    """the relative (to **job root**) filename of the File, final location is save_location/name"""

    created_at: builtins.int
    """when was this made"""

    is_input: builtins.bool
    """this was there when the run was created or this was created by the run as an output"""

    relic_key: typing.Text
    """RelicFile relic_file = 4; // this is the file when used with
    experiments/{project_name}/{experiment_id}/{relic_key}
    """

    def __init__(self,
        *,
        name: typing.Text = ...,
        created_at: builtins.int = ...,
        is_input: builtins.bool = ...,
        relic_key: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["created_at",b"created_at","is_input",b"is_input","name",b"name","relic_key",b"relic_key"]) -> None: ...
global___File = File

class FileList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    EXPERIMENT_ID_FIELD_NUMBER: builtins.int
    FILES_FIELD_NUMBER: builtins.int
    experiment_id: typing.Text
    """associated run"""

    @property
    def files(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___File]:
        """all the Files"""
        pass
    def __init__(self,
        *,
        experiment_id: typing.Text = ...,
        files: typing.Optional[typing.Iterable[global___File]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["experiment_id",b"experiment_id","files",b"files"]) -> None: ...
global___FileList = FileList

class Run(google.protobuf.message.Message):
    """the Big Object"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class _Status:
        ValueType = typing.NewType('ValueType', builtins.int)
        V: typing_extensions.TypeAlias = ValueType
    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Run._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        NOT_SET: Run._Status.ValueType  # 0
        """When created and added to DB but no further action taken"""

        RUNNING: Run._Status.ValueType  # 1
        """When the first on_log has been called"""

        COMPLETED: Run._Status.ValueType  # 2
        """When the on_train_end has been called"""

        FAILED: Run._Status.ValueType  # 3
        """When the NBX-Job failed"""

        DELETED: Run._Status.ValueType  # 4
        """When the run was deleted"""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper):
        pass

    NOT_SET: Run.Status.ValueType  # 0
    """When created and added to DB but no further action taken"""

    RUNNING: Run.Status.ValueType  # 1
    """When the first on_log has been called"""

    COMPLETED: Run.Status.ValueType  # 2
    """When the on_train_end has been called"""

    FAILED: Run.Status.ValueType  # 3
    """When the NBX-Job failed"""

    DELETED: Run.Status.ValueType  # 4
    """When the run was deleted"""


    WORKSPACE_ID_FIELD_NUMBER: builtins.int
    PROJECT_ID_FIELD_NUMBER: builtins.int
    PROJECT_NAME_FIELD_NUMBER: builtins.int
    EXPERIMENT_ID_FIELD_NUMBER: builtins.int
    AGENT_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    UPDATED_AT_FIELD_NUMBER: builtins.int
    ENDED_AT_FIELD_NUMBER: builtins.int
    SAVE_LOCATION_FIELD_NUMBER: builtins.int
    FILE_LIST_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    UPDATE_KEYS_FIELD_NUMBER: builtins.int
    workspace_id: typing.Text
    """the workspace this run is part of"""

    project_id: typing.Text
    """the project this run is part of"""

    project_name: typing.Text
    """the project this run is part of"""

    experiment_id: typing.Text
    """the unique ID of this run from the MongoDB backend"""

    @property
    def agent(self) -> global___AgentDetails:
        """the agent details"""
        pass
    created_at: builtins.int
    """same as InitRunRequest.created_at"""

    updated_at: builtins.int
    """the last time this run was updated"""

    ended_at: builtins.int
    """when was run declared dead, the actual kill can be well before that"""

    save_location: typing.Text
    """this is the location where the Files from this run are stored"""

    @property
    def file_list(self) -> global___FileList:
        """all the Files from this run"""
        pass
    config: typing.Text
    """the jsonified config string"""

    status: global___Run.Status.ValueType
    """the last known status of this run"""

    @property
    def update_keys(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]:
        """now we create a special thing which will be populated and sent during updates"""
        pass
    def __init__(self,
        *,
        workspace_id: typing.Text = ...,
        project_id: typing.Text = ...,
        project_name: typing.Text = ...,
        experiment_id: typing.Text = ...,
        agent: typing.Optional[global___AgentDetails] = ...,
        created_at: builtins.int = ...,
        updated_at: builtins.int = ...,
        ended_at: builtins.int = ...,
        save_location: typing.Text = ...,
        file_list: typing.Optional[global___FileList] = ...,
        config: typing.Text = ...,
        status: global___Run.Status.ValueType = ...,
        update_keys: typing.Optional[typing.Iterable[typing.Text]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["agent",b"agent","file_list",b"file_list"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["agent",b"agent","config",b"config","created_at",b"created_at","ended_at",b"ended_at","experiment_id",b"experiment_id","file_list",b"file_list","project_id",b"project_id","project_name",b"project_name","save_location",b"save_location","status",b"status","update_keys",b"update_keys","updated_at",b"updated_at","workspace_id",b"workspace_id"]) -> None: ...
global___Run = Run

class ListProjectsRequest(google.protobuf.message.Message):
    """
    Now we have the data structures for the user-client to get the data from the Konark.

    Request Reponse kind of thing
    $app/monitoring/
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    WORKSPACE_ID_FIELD_NUMBER: builtins.int
    PROJECT_ID_OR_NAME_FIELD_NUMBER: builtins.int
    PAGE_NO_FIELD_NUMBER: builtins.int
    workspace_id: typing.Text
    """the workspace this is part of"""

    project_id_or_name: typing.Text
    """used specifically for searching, if empty, it will return all the projects"""

    page_no: builtins.int
    def __init__(self,
        *,
        workspace_id: typing.Text = ...,
        project_id_or_name: typing.Text = ...,
        page_no: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["page_no",b"page_no","project_id_or_name",b"project_id_or_name","workspace_id",b"workspace_id"]) -> None: ...
global___ListProjectsRequest = ListProjectsRequest

class Project(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    WORKSPACE_ID_FIELD_NUMBER: builtins.int
    PROJECT_ID_FIELD_NUMBER: builtins.int
    PROJECT_NAME_FIELD_NUMBER: builtins.int
    TOTAL_RUNS_FIELD_NUMBER: builtins.int
    LOG_METRICS_FIELD_NUMBER: builtins.int
    CONFIG_METRICS_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    IS_DELETED_FIELD_NUMBER: builtins.int
    workspace_id: typing.Text
    """the workspace this is part of"""

    project_id: typing.Text
    """the unique ID for this project"""

    project_name: typing.Text
    """the usermodifiable name of the project"""

    total_runs: builtins.int
    """the total number of experiments in this project"""

    @property
    def log_metrics(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]:
        """the list of loggeed metrics in the project"""
        pass
    @property
    def config_metrics(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]:
        """the list of config metrics in the project"""
        pass
    created_at: builtins.int
    """the time when this project was created"""

    is_deleted: builtins.bool
    """if this project is deleted"""

    def __init__(self,
        *,
        workspace_id: typing.Text = ...,
        project_id: typing.Text = ...,
        project_name: typing.Text = ...,
        total_runs: builtins.int = ...,
        log_metrics: typing.Optional[typing.Iterable[typing.Text]] = ...,
        config_metrics: typing.Optional[typing.Iterable[typing.Text]] = ...,
        created_at: builtins.int = ...,
        is_deleted: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["config_metrics",b"config_metrics","created_at",b"created_at","is_deleted",b"is_deleted","log_metrics",b"log_metrics","project_id",b"project_id","project_name",b"project_name","total_runs",b"total_runs","workspace_id",b"workspace_id"]) -> None: ...
global___Project = Project

class ListProjectsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PROJECTS_FIELD_NUMBER: builtins.int
    TOTAL_PAGES_FIELD_NUMBER: builtins.int
    @property
    def projects(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Project]:
        """the list of projects in this workspace"""
        pass
    total_pages: builtins.int
    """the total number of pages"""

    def __init__(self,
        *,
        projects: typing.Optional[typing.Iterable[global___Project]] = ...,
        total_pages: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["projects",b"projects","total_pages",b"total_pages"]) -> None: ...
global___ListProjectsResponse = ListProjectsResponse

class ListRunsRequest(google.protobuf.message.Message):
    """$app/monitoring/gjj9dk30"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    WORKSPACE_ID_FIELD_NUMBER: builtins.int
    PROJECT_ID_FIELD_NUMBER: builtins.int
    EXPERIMENT_ID_FIELD_NUMBER: builtins.int
    PAGE_NO_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    workspace_id: typing.Text
    """the workspace this is part of"""

    project_id: typing.Text
    """the unique ID for this project"""

    experiment_id: typing.Text
    """for searching"""

    page_no: builtins.int
    desc: builtins.bool
    def __init__(self,
        *,
        workspace_id: typing.Text = ...,
        project_id: typing.Text = ...,
        experiment_id: typing.Text = ...,
        page_no: builtins.int = ...,
        desc: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["desc",b"desc","experiment_id",b"experiment_id","page_no",b"page_no","project_id",b"project_id","workspace_id",b"workspace_id"]) -> None: ...
global___ListRunsRequest = ListRunsRequest

class ListRunsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    EXPERIMENT_IDS_FIELD_NUMBER: builtins.int
    KEYS_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    TOTAL_PAGES_FIELD_NUMBER: builtins.int
    @property
    def experiment_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]:
        """the list of runs in this project"""
        pass
    @property
    def keys(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]:
        """the list of chart-keys for this run"""
        pass
    @property
    def created_at(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]:
        """time when these runs were created"""
        pass
    total_pages: builtins.int
    """the total number of pages"""

    def __init__(self,
        *,
        experiment_ids: typing.Optional[typing.Iterable[typing.Text]] = ...,
        keys: typing.Optional[typing.Iterable[typing.Text]] = ...,
        created_at: typing.Optional[typing.Iterable[builtins.int]] = ...,
        total_pages: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["created_at",b"created_at","experiment_ids",b"experiment_ids","keys",b"keys","total_pages",b"total_pages"]) -> None: ...
global___ListRunsResponse = ListRunsResponse

class RunLogRequest(google.protobuf.message.Message):
    """logs for $app/monitoring/gjj9dk30/experiment/cmk03kt03/"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    WORKSPACE_ID_FIELD_NUMBER: builtins.int
    PROJECT_ID_FIELD_NUMBER: builtins.int
    EXPERIMENT_ID_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    START_AT_FIELD_NUMBER: builtins.int
    END_AT_FIELD_NUMBER: builtins.int
    workspace_id: typing.Text
    project_id: typing.Text
    experiment_id: typing.Text
    """the unique ID for this run"""

    key: typing.Text
    """the key to search for, if empty, it will return all the logs"""

    start_at: builtins.int
    """the start at, default is 0"""

    end_at: builtins.int
    """the end at, default is -1"""

    def __init__(self,
        *,
        workspace_id: typing.Text = ...,
        project_id: typing.Text = ...,
        experiment_id: typing.Text = ...,
        key: typing.Text = ...,
        start_at: builtins.int = ...,
        end_at: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["end_at",b"end_at","experiment_id",b"experiment_id","key",b"key","project_id",b"project_id","start_at",b"start_at","workspace_id",b"workspace_id"]) -> None: ...
global___RunLogRequest = RunLogRequest

class Acknowledge(google.protobuf.message.Message):
    """generic response to any message"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SUCCESS_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    success: builtins.bool
    message: typing.Text
    """message can contain message or traceback if not success"""

    def __init__(self,
        *,
        success: builtins.bool = ...,
        message: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["message",b"message","success",b"success"]) -> None: ...
global___Acknowledge = Acknowledge

class GetExperimentTableRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    WORKSPACE_ID_FIELD_NUMBER: builtins.int
    PROJECT_ID_FIELD_NUMBER: builtins.int
    PAGE_NO_FIELD_NUMBER: builtins.int
    EXPERIMENT_ID_FIELD_NUMBER: builtins.int
    START_FIELD_NUMBER: builtins.int
    END_FIELD_NUMBER: builtins.int
    workspace_id: typing.Text
    project_id: typing.Text
    page_no: builtins.int
    experiment_id: typing.Text
    start: builtins.int
    """these two things will simply run the command => runs.experiment_ids[start:end]
    start: on this page start from here
    """

    end: builtins.int
    """end: on this page end till here"""

    def __init__(self,
        *,
        workspace_id: typing.Text = ...,
        project_id: typing.Text = ...,
        page_no: builtins.int = ...,
        experiment_id: typing.Text = ...,
        start: builtins.int = ...,
        end: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["end",b"end","experiment_id",b"experiment_id","page_no",b"page_no","project_id",b"project_id","start",b"start","workspace_id",b"workspace_id"]) -> None: ...
global___GetExperimentTableRequest = GetExperimentTableRequest

class ExperimentTable(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class Row(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        EXPERIMENT_ID_FIELD_NUMBER: builtins.int
        DATA_FIELD_NUMBER: builtins.int
        experiment_id: typing.Text
        """each row in the table is an experiment and all the columns generated against that experiment"""

        @property
        def data(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RecordColumn]:
            """here the len(data.rows) == 1"""
            pass
        def __init__(self,
            *,
            experiment_id: typing.Text = ...,
            data: typing.Optional[typing.Iterable[global___RecordColumn]] = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["data",b"data","experiment_id",b"experiment_id"]) -> None: ...

    TOTAL_PAGES_FIELD_NUMBER: builtins.int
    ROWS_FIELD_NUMBER: builtins.int
    total_pages: builtins.int
    """the big table object"""

    @property
    def rows(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ExperimentTable.Row]: ...
    def __init__(self,
        *,
        total_pages: builtins.int = ...,
        rows: typing.Optional[typing.Iterable[global___ExperimentTable.Row]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["rows",b"rows","total_pages",b"total_pages"]) -> None: ...
global___ExperimentTable = ExperimentTable

class Rule(google.protobuf.message.Message):
    """Alerting

    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    WORKSPACE_ID_FIELD_NUMBER: builtins.int
    PROJECT_ID_FIELD_NUMBER: builtins.int
    RULE_NAME_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    IS_DEACTIVATED_FIELD_NUMBER: builtins.int
    IS_DELETED_FIELD_NUMBER: builtins.int
    LOGIC_FIELD_NUMBER: builtins.int
    EMAIL_IDS_FIELD_NUMBER: builtins.int
    ALERT_MESSAGE_FIELD_NUMBER: builtins.int
    TRUE_COUNT_FIELD_NUMBER: builtins.int
    LOGIC_VERSION_FIELD_NUMBER: builtins.int
    MAX_RANGE_FIELD_NUMBER: builtins.int
    UPDATE_KEYS_FIELD_NUMBER: builtins.int
    workspace_id: typing.Text
    project_id: typing.Text
    rule_name: typing.Text
    created_at: builtins.int
    is_deactivated: builtins.bool
    is_deleted: builtins.bool
    logic: typing.Text
    """now we come to things around the logic and alerts themseleves
    the jsonified json_logic body
    """

    @property
    def email_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]:
        """the list of email ids to send the alert to"""
        pass
    alert_message: typing.Text
    """the message to send to the email ids"""

    true_count: builtins.int
    """this tells the number of times this rule has been broken"""

    logic_version: builtins.int
    """this tells the version number of the logic format that we are using, here's some
    details about them:
    0: the variables in functions have to be shifted by one
    1: the variables can be consume directly as they come
    """

    max_range: builtins.int
    """this is the number for maximum range from all the rules, this will be used to
    conviniently get the data from the tables
    """

    @property
    def update_keys(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]:
        """now we create a special thing which will be populated and sent during updates"""
        pass
    def __init__(self,
        *,
        workspace_id: typing.Text = ...,
        project_id: typing.Text = ...,
        rule_name: typing.Text = ...,
        created_at: builtins.int = ...,
        is_deactivated: builtins.bool = ...,
        is_deleted: builtins.bool = ...,
        logic: typing.Text = ...,
        email_ids: typing.Optional[typing.Iterable[typing.Text]] = ...,
        alert_message: typing.Text = ...,
        true_count: builtins.int = ...,
        logic_version: builtins.int = ...,
        max_range: builtins.int = ...,
        update_keys: typing.Optional[typing.Iterable[typing.Text]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["alert_message",b"alert_message","created_at",b"created_at","email_ids",b"email_ids","is_deactivated",b"is_deactivated","is_deleted",b"is_deleted","logic",b"logic","logic_version",b"logic_version","max_range",b"max_range","project_id",b"project_id","rule_name",b"rule_name","true_count",b"true_count","update_keys",b"update_keys","workspace_id",b"workspace_id"]) -> None: ...
global___Rule = Rule

class ListRules(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    WORKSPACE_ID_FIELD_NUMBER: builtins.int
    PROJECT_ID_FIELD_NUMBER: builtins.int
    PAGE_NO_FIELD_NUMBER: builtins.int
    TOTAL_PAGES_FIELD_NUMBER: builtins.int
    RULES_FIELD_NUMBER: builtins.int
    RULE_NAME_FIELD_NUMBER: builtins.int
    workspace_id: typing.Text
    project_id: typing.Text
    page_no: builtins.int
    total_pages: builtins.int
    @property
    def rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Rule]:
        """when sent to server, it will blindly update the rules and send it back"""
        pass
    rule_name: typing.Text
    """name of the rule if performing direct search"""

    def __init__(self,
        *,
        workspace_id: typing.Text = ...,
        project_id: typing.Text = ...,
        page_no: builtins.int = ...,
        total_pages: builtins.int = ...,
        rules: typing.Optional[typing.Iterable[global___Rule]] = ...,
        rule_name: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["page_no",b"page_no","project_id",b"project_id","rule_name",b"rule_name","rules",b"rules","total_pages",b"total_pages","workspace_id",b"workspace_id"]) -> None: ...
global___ListRules = ListRules

class RuleBuilder(google.protobuf.message.Message):
    """the purpose of this message is to help the FE in creating the UI"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class Op(google.protobuf.message.Message):
        """just like the ListRules message, the job of the server is to take the above two values
        and return the following fields populated, it will completely ignore the rest.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        SYMBOL_FIELD_NUMBER: builtins.int
        NAME_FIELD_NUMBER: builtins.int
        symbol: typing.Text
        """≠"""

        name: typing.Text
        """not equal"""

        def __init__(self,
            *,
            symbol: typing.Text = ...,
            name: typing.Text = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["name",b"name","symbol",b"symbol"]) -> None: ...

    class Fn(google.protobuf.message.Message):
        """list of functions that can be used in the logic, server side will tell what can done
        and what not. infact server side is the dumbest thing in the world, it will just blindly
        tell what is in the DB. So we can have immediate control vs. going through CI/CD.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        SYMBOL_FIELD_NUMBER: builtins.int
        NAME_FIELD_NUMBER: builtins.int
        FE_META_FIELD_NUMBER: builtins.int
        symbol: typing.Text
        """"avg" """

        name: typing.Text
        """"Average" """

        fe_meta: typing.Text
        """optional json-data for FE to use"""

        def __init__(self,
            *,
            symbol: typing.Text = ...,
            name: typing.Text = ...,
            fe_meta: typing.Text = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["fe_meta",b"fe_meta","name",b"name","symbol",b"symbol"]) -> None: ...

    WORKSPACE_ID_FIELD_NUMBER: builtins.int
    PROJECT_ID_FIELD_NUMBER: builtins.int
    METRICS_FIELD_NUMBER: builtins.int
    OPERATORS_FIELD_NUMBER: builtins.int
    FUNCTIONS_FIELD_NUMBER: builtins.int
    workspace_id: typing.Text
    project_id: typing.Text
    @property
    def metrics(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]:
        """the list of metrics"""
        pass
    @property
    def operators(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RuleBuilder.Op]:
        """the list of operators"""
        pass
    @property
    def functions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RuleBuilder.Fn]:
        """the list of functions"""
        pass
    def __init__(self,
        *,
        workspace_id: typing.Text = ...,
        project_id: typing.Text = ...,
        metrics: typing.Optional[typing.Iterable[typing.Text]] = ...,
        operators: typing.Optional[typing.Iterable[global___RuleBuilder.Op]] = ...,
        functions: typing.Optional[typing.Iterable[global___RuleBuilder.Fn]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["functions",b"functions","metrics",b"metrics","operators",b"operators","project_id",b"project_id","workspace_id",b"workspace_id"]) -> None: ...
global___RuleBuilder = RuleBuilder



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: lmao.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nlmao.proto\x12\x04lmao\x1a\x1fgoogle/protobuf/timestamp.proto\"i\n\tLogBuffer\x12\x13\n\x0b\x61gent_token\x18\x01 \x01(\t\x12\x1e\n\x08run_logs\x18\x02 \x03(\x0b\x32\x0c.lmao.RunLog\x12\'\n\tlive_logs\x18\x03 \x03(\x0b\x32\x14.lmao.ServingHTTPLog\"\x86\x01\n\x0eServingHTTPLog\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0e\n\x06method\x18\x02 \x01(\t\x12\x13\n\x0bstatus_code\x18\x03 \x01(\x05\x12\x12\n\nlatency_ms\x18\x04 \x01(\x02\x12-\n\ttimestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"[\n\x16ListDeploymentsRequest\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12\x1a\n\x12serving_id_or_name\x18\x02 \x01(\t\x12\x0f\n\x07page_no\x18\x03 \x01(\x05\"\xc7\x01\n\x17ListDeploymentsResponse\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12\x36\n\x07serving\x18\x02 \x03(\x0b\x32%.lmao.ListDeploymentsResponse.Serving\x12\x13\n\x0btotal_pages\x18\x03 \x01(\x05\x1aI\n\x07Serving\x12\x12\n\nserving_id\x18\x01 \x01(\t\x12\x14\n\x0cserving_name\x18\x02 \x01(\t\x12\x14\n\x0ctotal_models\x18\x03 \x01(\x05\"q\n\x13ListServingsRequest\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12\x15\n\rdeployment_id\x18\x02 \x01(\t\x12\x0e\n\x06run_id\x18\x03 \x01(\t\x12\x0f\n\x07page_no\x18\x04 \x01(\x05\x12\x0c\n\x04\x64\x65sc\x18\x05 \x01(\x08\"`\n\x14ListServingsResponse\x12\x11\n\tmodel_ids\x18\x01 \x03(\t\x12\x0c\n\x04keys\x18\x02 \x03(\t\x12\x12\n\ncreated_at\x18\x03 \x03(\x03\x12\x13\n\x0btotal_pages\x18\x04 \x01(\x05\"\xe8\x01\n\x07Serving\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12!\n\x05\x61gent\x18\x02 \x01(\x0b\x32\x12.lmao.AgentDetails\x12\x13\n\x0b\x61gent_token\x18\x03 \x01(\t\x12\x12\n\ncreated_at\x18\x04 \x01(\x03\x12\x0e\n\x06\x63onfig\x18\x05 \x01(\t\x12$\n\x06status\x18\x06 \x01(\x0e\x32\x14.lmao.Serving.Status\x12\x12\n\nupdated_at\x18\x07 \x01(\x03\"1\n\x06Status\x12\x0b\n\x07NOT_SET\x10\x00\x12\x0b\n\x07RUNNING\x10\x01\x12\r\n\tCOMPLETED\x10\x02\"\xbd\x01\n\x06Record\x12\x0b\n\x03key\x18\x01 \x01(\t\x12)\n\nvalue_type\x18\x02 \x01(\x0e\x32\x15.lmao.Record.DataType\x12\x0c\n\x04step\x18\x03 \x01(\x03\x12\x12\n\nfloat_data\x18\x64 \x03(\x02\x12\x14\n\x0cinteger_data\x18\x65 \x03(\x05\x12\x13\n\x0bstring_data\x18\x66 \x03(\t\".\n\x08\x44\x61taType\x12\t\n\x05\x46LOAT\x10\x00\x12\x0b\n\x07INTEGER\x10\x01\x12\n\n\x06STRING\x10\x02\"\xff\x01\n\x0cRecordColumn\x12\x0b\n\x03key\x18\x01 \x01(\t\x12/\n\nvalue_type\x18\x02 \x01(\x0e\x32\x1b.lmao.RecordColumn.DataType\x12*\n\x04rows\x18\x03 \x03(\x0b\x32\x1c.lmao.RecordColumn.RecordRow\x1aU\n\tRecordRow\x12\t\n\x01x\x18\x01 \x01(\x03\x12\x12\n\nfloat_data\x18\x64 \x01(\x02\x12\x14\n\x0cinteger_data\x18\x65 \x01(\x05\x12\x13\n\x0bstring_data\x18\x66 \x01(\t\".\n\x08\x44\x61taType\x12\t\n\x05\x46LOAT\x10\x00\x12\x0b\n\x07INTEGER\x10\x01\x12\n\n\x06STRING\x10\x02\"\xe0\x01\n\x06RunLog\x12\x15\n\rexperiment_id\x18\x01 \x01(\t\x12\x1a\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32\x0c.lmao.Record\x12\'\n\x0b\x63olumn_data\x18\x03 \x03(\x0b\x32\x12.lmao.RecordColumn\x12&\n\x08log_type\x18\x04 \x01(\x0e\x32\x14.lmao.RunLog.LogType\x12\x12\n\nproject_id\x18\x05 \x01(\t\x12\x14\n\x0cworkspace_id\x18\x06 \x01(\t\"(\n\x07LogType\x12\n\n\x06SYSTEM\x10\x00\x12\x07\n\x03NBX\x10\x01\x12\x08\n\x04USER\x10\x02\"\xd7\x01\n\x0c\x41gentDetails\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12$\n\x04type\x18\x02 \x01(\x0e\x32\x16.lmao.AgentDetails.NBX\x12\x14\n\nnbx_job_id\x18\x65 \x01(\tH\x00\x12\x18\n\x0enbx_serving_id\x18\x66 \x01(\tH\x00\x12\x14\n\nnbx_run_id\x18g \x01(\tH\x01\x12\x16\n\x0cnbx_model_id\x18h \x01(\tH\x01\"\x1b\n\x03NBX\x12\x07\n\x03JOB\x10\x00\x12\x0b\n\x07SERVING\x10\x01\x42\x04\n\x02idB\n\n\x08instance\"\x8b\x01\n\x0eInitRunRequest\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x14\n\x0cproject_name\x18\x03 \x01(\t\x12)\n\ragent_details\x18\x04 \x01(\x0b\x32\x12.lmao.AgentDetails\x12\x0e\n\x06\x63onfig\x18\x06 \x01(\t\"M\n\x04\x46ile\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ncreated_at\x18\x02 \x01(\x03\x12\x10\n\x08is_input\x18\x03 \x01(\x08\x12\x11\n\trelic_key\x18\x05 \x01(\t\"<\n\x08\x46ileList\x12\x15\n\rexperiment_id\x18\x01 \x01(\t\x12\x19\n\x05\x66iles\x18\x02 \x03(\x0b\x32\n.lmao.File\"\x86\x03\n\x03Run\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x14\n\x0cproject_name\x18\x03 \x01(\t\x12\x15\n\rexperiment_id\x18\x04 \x01(\t\x12!\n\x05\x61gent\x18\x05 \x01(\x0b\x32\x12.lmao.AgentDetails\x12\x12\n\ncreated_at\x18\x06 \x01(\x03\x12\x12\n\nupdated_at\x18\x07 \x01(\x03\x12\x10\n\x08\x65nded_at\x18\x08 \x01(\x03\x12\x15\n\rsave_location\x18\t \x01(\t\x12!\n\tfile_list\x18\n \x01(\x0b\x32\x0e.lmao.FileList\x12\x0e\n\x06\x63onfig\x18\x0b \x01(\t\x12 \n\x06status\x18\x0c \x01(\x0e\x32\x10.lmao.Run.Status\x12\x13\n\x0bupdate_keys\x18\x64 \x03(\t\"J\n\x06Status\x12\x0b\n\x07NOT_SET\x10\x00\x12\x0b\n\x07RUNNING\x10\x01\x12\r\n\tCOMPLETED\x10\x02\x12\n\n\x06\x46\x41ILED\x10\x03\x12\x0b\n\x07\x44\x45LETED\x10\x04\"X\n\x13ListProjectsRequest\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12\x1a\n\x12project_id_or_name\x18\x02 \x01(\t\x12\x0f\n\x07page_no\x18\x03 \x01(\x05\"\xb2\x01\n\x07Project\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x14\n\x0cproject_name\x18\x03 \x01(\t\x12\x12\n\ntotal_runs\x18\x04 \x01(\x05\x12\x13\n\x0blog_metrics\x18\x05 \x03(\t\x12\x16\n\x0e\x63onfig_metrics\x18\x06 \x03(\t\x12\x12\n\ncreated_at\x18\x07 \x01(\x03\x12\x12\n\nis_deleted\x18\x08 \x01(\x08\"L\n\x14ListProjectsResponse\x12\x1f\n\x08projects\x18\x01 \x03(\x0b\x32\r.lmao.Project\x12\x13\n\x0btotal_pages\x18\x02 \x01(\x05\"q\n\x0fListRunsRequest\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x15\n\rexperiment_id\x18\x03 \x01(\t\x12\x0f\n\x07page_no\x18\x04 \x01(\x05\x12\x0c\n\x04\x64\x65sc\x18\x05 \x01(\x08\"a\n\x10ListRunsResponse\x12\x16\n\x0e\x65xperiment_ids\x18\x01 \x03(\t\x12\x0c\n\x04keys\x18\x02 \x03(\t\x12\x12\n\ncreated_at\x18\x03 \x03(\x03\x12\x13\n\x0btotal_pages\x18\x04 \x01(\x05\"\x7f\n\rRunLogRequest\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x15\n\rexperiment_id\x18\x03 \x01(\t\x12\x0b\n\x03key\x18\x04 \x01(\t\x12\x10\n\x08start_at\x18\x05 \x01(\x05\x12\x0e\n\x06\x65nd_at\x18\x06 \x01(\x05\"/\n\x0b\x41\x63knowledge\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\"\x89\x01\n\x19GetExperimentTableRequest\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x0f\n\x07page_no\x18\x03 \x01(\x05\x12\x15\n\rexperiment_id\x18\x06 \x01(\t\x12\r\n\x05start\x18\x04 \x01(\x05\x12\x0b\n\x03\x65nd\x18\x05 \x01(\x05\"\x8f\x01\n\x0f\x45xperimentTable\x12\x13\n\x0btotal_pages\x18\x01 \x01(\x05\x12\'\n\x04rows\x18\x02 \x03(\x0b\x32\x19.lmao.ExperimentTable.Row\x1a>\n\x03Row\x12\x15\n\rexperiment_id\x18\x01 \x01(\t\x12 \n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32\x12.lmao.RecordColumn\"\x8f\x02\n\x04Rule\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x11\n\trule_name\x18\x03 \x01(\t\x12\x12\n\ncreated_at\x18\x04 \x01(\x03\x12\x16\n\x0eis_deactivated\x18\x05 \x01(\x08\x12\x12\n\nis_deleted\x18\x06 \x01(\x08\x12\r\n\x05logic\x18\x07 \x01(\t\x12\x11\n\temail_ids\x18\x08 \x03(\t\x12\x15\n\ralert_message\x18\t \x01(\t\x12\x12\n\ntrue_count\x18\n \x01(\x05\x12\x15\n\rlogic_version\x18\x0b \x01(\x05\x12\x11\n\tmax_range\x18\x0c \x01(\x05\x12\x13\n\x0bupdate_keys\x18\x64 \x03(\t\"\x89\x01\n\tListRules\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x0f\n\x07page_no\x18\x03 \x01(\x05\x12\x13\n\x0btotal_pages\x18\x04 \x01(\x05\x12\x19\n\x05rules\x18\x05 \x03(\x0b\x32\n.lmao.Rule\x12\x11\n\trule_name\x18\x06 \x01(\t\"\xf3\x01\n\x0bRuleBuilder\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x0f\n\x07metrics\x18\x03 \x03(\t\x12\'\n\toperators\x18\x04 \x03(\x0b\x32\x14.lmao.RuleBuilder.Op\x12\'\n\tfunctions\x18\x05 \x03(\x0b\x32\x14.lmao.RuleBuilder.Fn\x1a\"\n\x02Op\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x1a\x33\n\x02\x46n\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07\x66\x65_meta\x18\x03 \x01(\t2\xeb\n\n\x04LMAO\x12-\n\x08init_run\x12\x14.lmao.InitRunRequest\x1a\t.lmao.Run\"\x00\x12\x33\n\x11update_run_status\x12\t.lmao.Run\x1a\x11.lmao.Acknowledge\"\x00\x12+\n\x06on_log\x12\x0c.lmao.RunLog\x1a\x11.lmao.Acknowledge\"\x00\x12.\n\x07on_save\x12\x0e.lmao.FileList\x1a\x11.lmao.Acknowledge\"\x00\x12.\n\x0con_train_end\x12\t.lmao.Run\x1a\x11.lmao.Acknowledge\"\x00\x12H\n\rlist_projects\x12\x19.lmao.ListProjectsRequest\x1a\x1a.lmao.ListProjectsResponse\"\x00\x12<\n\tlist_runs\x12\x15.lmao.ListRunsRequest\x1a\x16.lmao.ListRunsResponse\"\x00\x12P\n\x14get_experiment_table\x12\x1f.lmao.GetExperimentTableRequest\x1a\x15.lmao.ExperimentTable\"\x00\x12)\n\x0fget_run_details\x12\t.lmao.Run\x1a\t.lmao.Run\"\x00\x12\x32\n\x0bget_run_log\x12\x13.lmao.RunLogRequest\x1a\x0c.lmao.RunLog\"\x00\x12)\n\nlist_files\x12\t.lmao.Run\x1a\x0e.lmao.FileList\"\x00\x12\x33\n\x11\x64\x65lete_experiment\x12\t.lmao.Run\x1a\x11.lmao.Acknowledge\"\x00\x12\x34\n\x0e\x64\x65lete_project\x12\r.lmao.Project\x1a\x11.lmao.Acknowledge\"\x00\x12\x35\n\x0cinit_serving\x12\x14.lmao.InitRunRequest\x1a\r.lmao.Serving\"\x00\x12\x36\n\x0eon_serving_log\x12\x0f.lmao.LogBuffer\x1a\x11.lmao.Acknowledge\"\x00\x12\x34\n\x0eon_serving_end\x12\r.lmao.Serving\x1a\x11.lmao.Acknowledge\"\x00\x12Q\n\x10list_deployments\x12\x1c.lmao.ListDeploymentsRequest\x1a\x1d.lmao.ListDeploymentsResponse\"\x00\x12H\n\rlist_servings\x12\x19.lmao.ListServingsRequest\x1a\x1a.lmao.ListServingsResponse\"\x00\x12\x35\n\x13get_serving_details\x12\r.lmao.Serving\x1a\r.lmao.Serving\"\x00\x12\x33\n\x0fget_serving_log\x12\r.lmao.Serving\x1a\x0f.lmao.LogBuffer\"\x00\x12\'\n\x0b\x63reate_rule\x12\n.lmao.Rule\x1a\n.lmao.Rule\"\x00\x12\x30\n\nlist_rules\x12\x0f.lmao.ListRules\x1a\x0f.lmao.ListRules\"\x00\x12.\n\x0b\x64\x65lete_rule\x12\n.lmao.Rule\x1a\x11.lmao.Acknowledge\"\x00\x12.\n\x0bupdate_rule\x12\n.lmao.Rule\x1a\x11.lmao.Acknowledge\"\x00\x12:\n\x10get_rule_builder\x12\x11.lmao.RuleBuilder\x1a\x11.lmao.RuleBuilder\"\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'lmao_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _LOGBUFFER._serialized_start=53
  _LOGBUFFER._serialized_end=158
  _SERVINGHTTPLOG._serialized_start=161
  _SERVINGHTTPLOG._serialized_end=295
  _LISTDEPLOYMENTSREQUEST._serialized_start=297
  _LISTDEPLOYMENTSREQUEST._serialized_end=388
  _LISTDEPLOYMENTSRESPONSE._serialized_start=391
  _LISTDEPLOYMENTSRESPONSE._serialized_end=590
  _LISTDEPLOYMENTSRESPONSE_SERVING._serialized_start=517
  _LISTDEPLOYMENTSRESPONSE_SERVING._serialized_end=590
  _LISTSERVINGSREQUEST._serialized_start=592
  _LISTSERVINGSREQUEST._serialized_end=705
  _LISTSERVINGSRESPONSE._serialized_start=707
  _LISTSERVINGSRESPONSE._serialized_end=803
  _SERVING._serialized_start=806
  _SERVING._serialized_end=1038
  _SERVING_STATUS._serialized_start=989
  _SERVING_STATUS._serialized_end=1038
  _RECORD._serialized_start=1041
  _RECORD._serialized_end=1230
  _RECORD_DATATYPE._serialized_start=1184
  _RECORD_DATATYPE._serialized_end=1230
  _RECORDCOLUMN._serialized_start=1233
  _RECORDCOLUMN._serialized_end=1488
  _RECORDCOLUMN_RECORDROW._serialized_start=1355
  _RECORDCOLUMN_RECORDROW._serialized_end=1440
  _RECORDCOLUMN_DATATYPE._serialized_start=1184
  _RECORDCOLUMN_DATATYPE._serialized_end=1230
  _RUNLOG._serialized_start=1491
  _RUNLOG._serialized_end=1715
  _RUNLOG_LOGTYPE._serialized_start=1675
  _RUNLOG_LOGTYPE._serialized_end=1715
  _AGENTDETAILS._serialized_start=1718
  _AGENTDETAILS._serialized_end=1933
  _AGENTDETAILS_NBX._serialized_start=1888
  _AGENTDETAILS_NBX._serialized_end=1915
  _INITRUNREQUEST._serialized_start=1936
  _INITRUNREQUEST._serialized_end=2075
  _FILE._serialized_start=2077
  _FILE._serialized_end=2154
  _FILELIST._serialized_start=2156
  _FILELIST._serialized_end=2216
  _RUN._serialized_start=2219
  _RUN._serialized_end=2609
  _RUN_STATUS._serialized_start=2535
  _RUN_STATUS._serialized_end=2609
  _LISTPROJECTSREQUEST._serialized_start=2611
  _LISTPROJECTSREQUEST._serialized_end=2699
  _PROJECT._serialized_start=2702
  _PROJECT._serialized_end=2880
  _LISTPROJECTSRESPONSE._serialized_start=2882
  _LISTPROJECTSRESPONSE._serialized_end=2958
  _LISTRUNSREQUEST._serialized_start=2960
  _LISTRUNSREQUEST._serialized_end=3073
  _LISTRUNSRESPONSE._serialized_start=3075
  _LISTRUNSRESPONSE._serialized_end=3172
  _RUNLOGREQUEST._serialized_start=3174
  _RUNLOGREQUEST._serialized_end=3301
  _ACKNOWLEDGE._serialized_start=3303
  _ACKNOWLEDGE._serialized_end=3350
  _GETEXPERIMENTTABLEREQUEST._serialized_start=3353
  _GETEXPERIMENTTABLEREQUEST._serialized_end=3490
  _EXPERIMENTTABLE._serialized_start=3493
  _EXPERIMENTTABLE._serialized_end=3636
  _EXPERIMENTTABLE_ROW._serialized_start=3574
  _EXPERIMENTTABLE_ROW._serialized_end=3636
  _RULE._serialized_start=3639
  _RULE._serialized_end=3910
  _LISTRULES._serialized_start=3913
  _LISTRULES._serialized_end=4050
  _RULEBUILDER._serialized_start=4053
  _RULEBUILDER._serialized_end=4296
  _RULEBUILDER_OP._serialized_start=4209
  _RULEBUILDER_OP._serialized_end=4243
  _RULEBUILDER_FN._serialized_start=4245
  _RULEBUILDER_FN._serialized_end=4296
  _LMAO._serialized_start=4299
  _LMAO._serialized_end=5686
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from ..jobs import dag_pb2 as jobs_dot_dag__pb2
from ..jobs import job_pb2 as jobs_dot_job__pb2
from timeless import timeless_pb2 as timeless_dot_timeless__pb2


class TimelessStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetRandomDag = channel.unary_unary(
                '/timeless.Timeless/GetRandomDag',
                request_serializer=timeless_dot_timeless__pb2.RandomDAGRequest.SerializeToString,
                response_deserializer=jobs_dot_dag__pb2.DAG.FromString,
                )
        self.FillJobsFlow = channel.unary_unary(
                '/timeless.Timeless/FillJobsFlow',
                request_serializer=jobs_dot_job__pb2.Job.SerializeToString,
                response_deserializer=jobs_dot_job__pb2.Job.FromString,
                )


class TimelessServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetRandomDag(self, request, context):
        """method to get any RandomDag
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FillJobsFlow(self, request, context):
        """method to populate a Job with DAG
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TimelessServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetRandomDag': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRandomDag,
                    request_deserializer=timeless_dot_timeless__pb2.RandomDAGRequest.FromString,
                    response_serializer=jobs_dot_dag__pb2.DAG.SerializeToString,
            ),
            'FillJobsFlow': grpc.unary_unary_rpc_method_handler(
                    servicer.FillJobsFlow,
                    request_deserializer=jobs_dot_job__pb2.Job.FromString,
                    response_serializer=jobs_dot_job__pb2.Job.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'timeless.Timeless', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Timeless(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetRandomDag(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/timeless.Timeless/GetRandomDag',
            timeless_dot_timeless__pb2.RandomDAGRequest.SerializeToString,
            jobs_dot_dag__pb2.DAG.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FillJobsFlow(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/timeless.Timeless/FillJobsFlow',
            jobs_dot_job__pb2.Job.SerializeToString,
            jobs_dot_job__pb2.Job.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
